New RPCs
--------

- `getdescriptoractivity` can be used to find all spend/receive activity relevant to
  a given set of descriptors within a set of specified blocks. This call can be used with
  `scanblocks` to lessen the need for additional indexing programs.
